@@ -148,6 +148,7 @@ class Qubik(KaitaiStruct):
     :field datarate_tracking: osdlp_tm_frame.tm_tf_data_field.payload.datarate_tracking
     :field phase_tracking: osdlp_tm_frame.tm_tf_data_field.payload.phase_tracking
     :field rf_freq_tracking: osdlp_tm_frame.tm_tf_data_field.payload.rf_freq_tracking
+    :field trx_delay_ms: osdlp_tm_frame.tm_tf_data_field.payload.trx_delay_ms
     """
     def __init__(self, _io, _parent=None, _root=None):
         self._io = _io
@@ -227,6 +228,7 @@ class Qubik(KaitaiStruct):
             self.datarate_tracking = self._io.read_s4be()
             self.phase_tracking = self._io.read_s2be()
             self.rf_freq_tracking = self._io.read_s4be()
+            self.trx_delay_ms = self._io.read_u2be()
 
 
     class VcidExperimentT(KaitaiStruct):
